# eric7.Preferences.ThemeManager

Module implementing a manager object for color themes.

### Global Attributes

None

### Classes

ThemeManager | Class implementing a manager object for color themes.

### Functions

None

## ThemeManager

Class implementing a manager object for color themes.

### Derived from

QObject

### Class Attributes

ColorKeyList
ColorKeyPatternList

### Class Methods

None

### Methods

ThemeManager | Constructor
exportTheme | Public method to export the current colors to a theme file.
importTheme | Public method to import a theme file and set the colors.

### Static Methods

None

#### ThemeManager (Constructor)

ThemeManager(parent: QObject = None)

Constructor

parent (QObject (optional))
  reference to the parent object (defaults to None)

#### ThemeManager.exportTheme

exportTheme()

Public method to export the current colors to a theme file.

#### ThemeManager.importTheme

importTheme()

Public method to import a theme file and set the colors.

Return:
  flag indicating a successful import

Return Type:
  bool

Up